owl2else
=========

Scripts to transform ontology OWL 2 files to other languages
  
   - owl2clips transforms OWL 2 ontologies to COOL CLIPS language
   - owl2plot transforms OWL 2 ontologies to a plot using graphviz
   - owl2rdflib transforms OWL 2 to a python file with a RDFlib 
     ClosedNamespace object with the vocabulary of the ontology